Installing Credmgr
==================

Credmgr supports Python 3.6+. The recommended way to install credmgr is via ``pip``.

.. code-block:: bash

    pip install credmgr

Updating Credmgr
----------------

Credmgr can be updated by running:

.. code-block:: bash

    pip install --upgrade credmgr
